@@ -24,6 +24,7 @@
 #endif
 
 #include <gnome.h>
+#include <string.h>
 
 #include "button.h"
 #include "stock.h"
@@ -74,14 +75,29 @@ cb_record_toggled (GnomeVolumeControlButton *button,
 		        gnome_volume_control_button_get_active (button));
 }
 
+/* Tells us whether toggling a switch should change the corresponding
+ * GstMixerTrack's MUTE or RECORD flag.
+ */
+static gboolean
+should_toggle_record_switch (const GstMixerTrack *track)
+{
+  return GST_MIXER_TRACK_HAS_FLAG (track, GST_MIXER_TRACK_INPUT);
+}
+ 
+
 static void
 cb_toggle_changed (GtkToggleButton *button,
 		   gpointer         data)
 {
   GnomeVolumeControlTrack *ctrl = data;
 
-  gst_mixer_set_mute (ctrl->mixer, ctrl->track,
-		      !gtk_toggle_button_get_active (button));
+  if (should_toggle_record_switch (ctrl->track)) {
+    gst_mixer_set_record (ctrl->mixer, ctrl->track,
+      gtk_toggle_button_get_active (button));
+  } else {
+    gst_mixer_set_mute (ctrl->mixer, ctrl->track,
+      !gtk_toggle_button_get_active (button));
+  }
 }
 
 static void
@@ -109,6 +125,14 @@ static gboolean
 cb_check (gpointer data)
 {
   GnomeVolumeControlTrack *trkw = data;
+
+  /* trigger an update of the mixer state */
+  if (! GST_IS_MIXER_OPTIONS (trkw->track)) {
+    gint *dummy = g_new (gint, 1);
+    gst_mixer_get_volume (trkw->mixer, GST_MIXER_TRACK (trkw->track), dummy);
+    g_free (dummy);
+  }
+  
   gboolean mute = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
 				GST_MIXER_TRACK_MUTE) ? TRUE : FALSE,
            record = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
@@ -136,20 +160,20 @@ cb_check (gpointer data)
   }
 
   if (trkw->toggle) {
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (trkw->toggle)) ==
-            mute) {
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (trkw->toggle), !mute);
+    if (should_toggle_record_switch (trkw->track)) {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (trkw->toggle),
+        GST_MIXER_TRACK_HAS_FLAG (trkw->track, GST_MIXER_TRACK_RECORD));
+    } else {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (trkw->toggle),
+        !GST_MIXER_TRACK_HAS_FLAG (trkw->track, GST_MIXER_TRACK_MUTE));
     }
   }
 
   /* FIXME:
    * - options.
-   * - we cannot check flags! We need a _get_*() function in the
-   *     mixer interface, because flags don't change if other
-   *     apps change device state.
    */
 
-  return (trkw->mute || trkw->record);
+  return TRUE;
 }
 
 /*
@@ -180,7 +204,7 @@ gnome_volume_control_track_add_title (GtkTable *table,
   ctrl->visible = TRUE;
   ctrl->table = table;
   ctrl->pos = tab_pos;
-  ctrl->id = g_timeout_add (100, cb_check, ctrl);
+  ctrl->id = g_timeout_add (200, cb_check, ctrl);
 
   /* image (optional) */
   for (i = 0; !found && pix[i].label != NULL; i++) {
@@ -327,13 +351,13 @@ gnome_volume_control_track_add_playback	(GtkTable *table,
 }
 
 GnomeVolumeControlTrack *
-gnome_volume_control_track_add_capture (GtkTable *table,
-					gint      tab_pos,
-					GstMixer *mixer,
-					GstMixerTrack *track,
-					GtkWidget *l_sep,
-					GtkWidget *r_sep,
-					GnomeAppBar *appbar)
+gnome_volume_control_track_add_recording (GtkTable *table,
+					  gint      tab_pos,
+					  GstMixer *mixer,
+					  GstMixerTrack *track,
+					  GtkWidget *l_sep,
+					  GtkWidget *r_sep,
+					  GnomeAppBar *appbar)
 {
   GnomeVolumeControlTrack *ctrl;
   GtkWidget *button;
@@ -353,7 +377,7 @@ gnome_volume_control_track_add_capture (GtkTable *table,
    */
 
   /* only the record button here */
-  msg = g_strdup_printf (_("Toggle audio capture from %s"), ctrl->track->label);
+  msg = g_strdup_printf (_("Toggle audio recording from %s"), ctrl->track->label);
   button = gnome_volume_control_button_new (GNOME_VOLUME_CONTROL_STOCK_RECORD,
 					    GNOME_VOLUME_CONTROL_STOCK_NORECORD,
 					    appbar, msg);
@@ -368,7 +392,7 @@ gnome_volume_control_track_add_capture (GtkTable *table,
   /* a11y */
   accessible = gtk_widget_get_accessible (button);
   if (GTK_IS_ACCESSIBLE (accessible)) {
-    accessible_name = g_strdup_printf (_("Track %s: audio capture"),
+    accessible_name = g_strdup_printf (_("Track %s: audio recording"),
 				       track->label);
     atk_object_set_name (accessible, accessible_name);
     g_free (accessible_name);
@@ -398,9 +422,13 @@ gnome_volume_control_track_add_switch (GtkTable *table,
 					       GTK_ORIENTATION_HORIZONTAL,
 					       mixer, track, l_sep, r_sep);
   ctrl->toggle = gtk_check_button_new ();
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ctrl->toggle),
-				!GST_MIXER_TRACK_HAS_FLAG (ctrl->track,
-					GST_MIXER_TRACK_MUTE));
+  if (should_toggle_record_switch (ctrl->track)) {
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ctrl->toggle),
+      GST_MIXER_TRACK_HAS_FLAG (ctrl->track, GST_MIXER_TRACK_RECORD));
+  } else {
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ctrl->toggle),
+      !GST_MIXER_TRACK_HAS_FLAG (ctrl->track, GST_MIXER_TRACK_MUTE));
+  }
 
   /* attach'n'show */
   gtk_table_attach (GTK_TABLE (table), ctrl->toggle,
@@ -468,8 +496,10 @@ gnome_volume_control_track_add_option (GtkTable *table,
 void
 gnome_volume_control_track_free (GnomeVolumeControlTrack *track)
 {
-  if (track->id != 0)
+  if (track->id != 0) {
     g_source_remove (track->id);
+    track->id = 0;
+  }
 
   g_object_unref (G_OBJECT (track->track));
 
