@@ -23,14 +23,16 @@
 #include "config.h"
 #endif
 
+#define _ISOC99_SOURCE
+
+#include <math.h>
 #include <gnome.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <gst/mixer/mixer.h>
 
+#include "volume.h"
 #include "button.h"
 #include "stock.h"
-#include "volume.h"
 
 static void	gnome_volume_control_volume_class_init	(GnomeVolumeControlVolumeClass *klass);
 static void	gnome_volume_control_volume_init	(GnomeVolumeControlVolume *el);
@@ -183,9 +185,9 @@ get_scale (GnomeVolumeControlVolume *vol,
   gchar *accessible_name;
 
   adj = gtk_adjustment_new (volume,
-			    vol->track->min_volume,
-			    vol->track->max_volume,
-			    1.0, 1.0, 0.0);
+		vol->track->min_volume, vol->track->max_volume,
+		(vol->track->max_volume - vol->track->min_volume) / 100,
+		(vol->track->max_volume - vol->track->min_volume) / 10, 0.0);
   g_signal_connect (adj, "value_changed",
 		    G_CALLBACK (cb_volume_changed), vol);
   slider = gtk_vscale_new (GTK_ADJUSTMENT (adj));
@@ -226,7 +228,7 @@ get_button (GnomeVolumeControlVolume *vol,
   gchar *accessible_name, *msg;
   gint n;
 
-  msg = g_strdup_printf (("Lock channels for %s together"), vol->track->label);
+  msg = g_strdup_printf (_("Lock channels for %s together"), vol->track->label);
   vol->button = gnome_volume_control_button_new ("chain.png",
 						 "chain-broken.png",
 						 vol->appbar, msg);
@@ -477,9 +479,9 @@ cb_volume_changed (GtkAdjustment *_adj,
     if (gnome_volume_control_button_get_active (
             GNOME_VOLUME_CONTROL_BUTTON (vol->button))) {
       gtk_adjustment_set_value (adj, gtk_adjustment_get_value (_adj));
-      volumes[i++] = gtk_adjustment_get_value (_adj);
+      volumes[i++] = rint (gtk_adjustment_get_value (_adj));
     } else {
-      volumes[i++] = gtk_adjustment_get_value (adj);
+      volumes[i++] = rint (gtk_adjustment_get_value (adj));
     }
   }
 
@@ -489,6 +491,16 @@ cb_volume_changed (GtkAdjustment *_adj,
   vol->locked = FALSE;
 }
 
+/*
+ * To be called after unmuting.
+ */
+
+void
+gnome_volume_control_volume_sync (GnomeVolumeControlVolume * vol)
+{
+  cb_volume_changed (gtk_range_get_adjustment (vol->scales->data), vol);
+}
+
 static void
 cb_lock_toggled (GtkToggleButton *button,
 		 gpointer         data)
@@ -518,6 +530,36 @@ cb_lock_toggled (GtkToggleButton *button,
   }
 }
 
+/*
+ * See if our volume is zero.
+ */
+
+void
+gnome_volume_control_volume_ask (GnomeVolumeControlVolume * vol,
+    gboolean *real_zero, gboolean *slider_zero)
+{
+  GList *scales;
+  gint *volumes, n, tot = 0;
+
+  volumes = g_new (gint, vol->track->num_channels);
+  gst_mixer_get_volume (vol->mixer, vol->track, volumes);
+  for (n = 0; n < vol->track->num_channels; n++)
+    tot += volumes[n];
+  g_free (volumes);
+  *real_zero = (tot == 0);
+
+  *slider_zero = TRUE;
+  for (n = 0, scales = vol->scales;
+       scales != NULL; scales = scales->next, n++) {
+    GtkAdjustment *adj = gtk_range_get_adjustment (scales->data);
+                                                                                
+    if (rint (gtk_adjustment_get_value (adj)) != 0) {
+      *slider_zero = FALSE;
+      break;
+    }
+  }
+}
+
 /*
  * Timeout to check for volume changes.
  */
@@ -526,7 +568,8 @@ static gboolean
 cb_check (gpointer data)
 {
   GnomeVolumeControlVolume *vol = data;
-  gint *volumes, n = 0;
+  gint *volumes, n;
+  gboolean real_zero, slider_zero;
   GList *scales;
 
   /* don't do callbacks */
@@ -536,9 +579,17 @@ cb_check (gpointer data)
 
   volumes = g_new (gint, vol->track->num_channels);
   gst_mixer_get_volume (vol->mixer, vol->track, volumes);
+  gnome_volume_control_volume_ask (vol, &real_zero, &slider_zero);
+  if (real_zero || GST_MIXER_TRACK_HAS_FLAG (vol->track,
+					     GST_MIXER_TRACK_MUTE)) {
+    g_free (volumes);
+    vol->locked = FALSE;
+    return TRUE;
+  }
 
   /* did we change? */
-  for (scales = vol->scales; scales != NULL; scales = scales->next, n++) {
+  for (n = 0, scales = vol->scales;
+       scales != NULL; scales = scales->next, n++) {
     GtkAdjustment *adj = gtk_range_get_adjustment (scales->data);
 
     if ((gint) gtk_adjustment_get_value (adj) != volumes[n]) {
