@@ -47,104 +47,104 @@ extern GSTPPipelineDescription audiosrc_pipelines[];
 extern GSTPPipelineDescription videosrc_pipelines[];
 
 GSTPPipelineDescription audiosink_pipelines[] = {
-  {PIPE_TYPE_AUDIOSINK, 0, "Autodetect", "autoaudiosink", FALSE,
+  {PIPE_TYPE_AUDIOSINK, 0, N_("Autodetect"), "autoaudiosink", NULL, FALSE,
       TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
-  {PIPE_TYPE_AUDIOSINK, 0, "ALSA - Advanced Linux Sound Architecture",
-      "alsasink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
+  {PIPE_TYPE_AUDIOSINK, 0, N_("ALSA - Advanced Linux Sound Architecture"),
+      "alsasink", NULL, FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
 #if 0
   {PIPE_TYPE_AUDIOSINK, 0,
         "ALSA - Advanced Linux Sound Architecture (Default Device)",
-      "alsasink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
+      "alsasink", NULL, FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
   {PIPE_TYPE_AUDIOSINK, 0,
         "ALSA - Advanced Linux Sound Architecture (Sound Card #1 Direct)",
-        "alsasink device=hw:0", FALSE, TEST_PIPE_SUPPLIED,
+        "alsasink device=hw:0", NULL, FALSE, TEST_PIPE_SUPPLIED,
       audiosink_test_pipe, FALSE},
   {PIPE_TYPE_AUDIOSINK, 0,
         "ALSA - Advanced Linux Sound Architecture (Sound Card #1 DMix)",
-        "alsasink device=dmix:0", FALSE, TEST_PIPE_SUPPLIED,
+        "alsasink device=dmix:0", NULL, FALSE, TEST_PIPE_SUPPLIED,
       audiosink_test_pipe, FALSE},
 #endif
-  {PIPE_TYPE_AUDIOSINK, 0, "Artsd - ART Sound Daemon",
-      "artsdsink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
-  {PIPE_TYPE_AUDIOSINK, 0, "ESD - Enlightenment Sound Daemon",
-      "esdsink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
+  {PIPE_TYPE_AUDIOSINK, 0, N_("Artsd - ART Sound Daemon"),
+      "artsdsink", NULL, FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
+  {PIPE_TYPE_AUDIOSINK, 0, N_("ESD - Enlightenment Sound Daemon"),
+      "esdsink", NULL, FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
 #if 0                           /* Disabled this until it works */
-  {PIPE_TYPE_AUDIOSINK, 0, "Jack", "jackbin.( jacksink )", FALSE,
+  {PIPE_TYPE_AUDIOSINK, 0, "Jack", "jackbin.( jacksink )", NULL, FALSE,
       TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
 #endif
-  {PIPE_TYPE_AUDIOSINK, 0, "OSS - Open Sound System",
-      "osssink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, TRUE},
-  {PIPE_TYPE_AUDIOSINK, 0, "Pulse - PulseAudio Sound Server",
-      "pulsesink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
-  {PIPE_TYPE_AUDIOSINK, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_SUPPLIED,
+  {PIPE_TYPE_AUDIOSINK, 0, N_("OSS - Open Sound System"),
+      "osssink", NULL, FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, TRUE},
+  {PIPE_TYPE_AUDIOSINK, 0, N_("Pulse - PulseAudio Sound Server"),
+      "pulsesink", NULL, FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
+  {PIPE_TYPE_AUDIOSINK, 0, N_("Custom"), NULL, NULL, TRUE, TEST_PIPE_SUPPLIED,
       audiosink_test_pipe, TRUE}
 };
 
 GSTPPipelineDescription videosink_pipelines[] = {
-  {PIPE_TYPE_VIDEOSINK, 0, "Autodetect", "autovideosink", FALSE,
+  {PIPE_TYPE_VIDEOSINK, 0, N_("Autodetect"), "autovideosink", NULL, FALSE,
       TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
 #if 0
   /*
    * aasink is disabled because it is not a serious alternative.
    */
-  {PIPE_TYPE_VIDEOSINK, 0, "Ascii Art - X11", "aasink driver=0", FALSE,
+  {PIPE_TYPE_VIDEOSINK, 0, "Ascii Art - X11", "aasink driver=0", NULL, FALSE,
       TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
-  {PIPE_TYPE_VIDEOSINK, 0, "Ascii Art - console", "aasink driver=1", FALSE,
+  {PIPE_TYPE_VIDEOSINK, 0, "Ascii Art - console", "aasink driver=1", NULL, FALSE,
       TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
 #endif
 #if 0
   /* Leaving this one disabled, because of a bug in cacasink that
    * pops up a window in NULL state
    */
-  {PIPE_TYPE_VIDEOSINK, 0, "Colour Ascii Art", "cacasink", FALSE,
+  {PIPE_TYPE_VIDEOSINK, 0, "Colour Ascii Art", "cacasink", NULL, FALSE,
       TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
 #endif
-  {PIPE_TYPE_VIDEOSINK, 0, "SDL - Simple DirectMedia Layer", "sdlvideosink",
+  {PIPE_TYPE_VIDEOSINK, 0, N_("SDL - Simple DirectMedia Layer"), "sdlvideosink",
+      NULL, FALSE, TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
+  {PIPE_TYPE_VIDEOSINK, 0, N_("X Window System (No Xv)"),
+      "ximagesink", NULL, FALSE, TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
+  {PIPE_TYPE_VIDEOSINK, 0, N_("X Window System (X11/XShm/Xv)"), "xvimagesink", NULL,
       FALSE, TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
-  {PIPE_TYPE_VIDEOSINK, 0, "X Window System (No Xv)",
-      "ximagesink", FALSE, TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
-  {PIPE_TYPE_VIDEOSINK, 0, "X Window System (X11/XShm/Xv)", "xvimagesink", FALSE,
-      TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
-  {PIPE_TYPE_VIDEOSINK, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_SUPPLIED,
+  {PIPE_TYPE_VIDEOSINK, 0, N_("Custom"), NULL, NULL, TRUE, TEST_PIPE_SUPPLIED,
       videosink_test_pipe, TRUE}
 };
 
 GSTPPipelineDescription audiosrc_pipelines[] = {
-  {PIPE_TYPE_AUDIOSRC, 0, "ALSA - Advanced Linux Sound Architecture",
-      "alsasrc", FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
-  {PIPE_TYPE_AUDIOSRC, 0, "ESD - Enlightenment Sound Daemon", "esdmon",
-      FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
+  {PIPE_TYPE_AUDIOSRC, 0, N_("ALSA - Advanced Linux Sound Architecture"),
+      "alsasrc", NULL, FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
+  {PIPE_TYPE_AUDIOSRC, 0, N_("ESD - Enlightenment Sound Daemon"), "esdmon",
+      NULL, FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
 #if 0                           /* Disabled this until it works */
-  {PIPE_TYPE_AUDIOSRC, 0, "Jack", "jackbin{ jacksrc }", FALSE,
+  {PIPE_TYPE_AUDIOSRC, 0, "Jack", "jackbin{ jacksrc }", NULL, FALSE,
         TEST_PIPE_AUDIOSINK,
       NULL, FALSE},
 #endif
-  {PIPE_TYPE_AUDIOSRC, 0, "OSS - Open Sound System", "osssrc", FALSE,
-      TEST_PIPE_AUDIOSINK, NULL, FALSE},
-  {PIPE_TYPE_AUDIOSRC, 0, "Pulse - PulseAudio Sound Server", "pulsesrc", FALSE,
+  {PIPE_TYPE_AUDIOSRC, 0, N_("OSS - Open Sound System"), "osssrc", NULL, FALSE,
       TEST_PIPE_AUDIOSINK, NULL, FALSE},
+  {PIPE_TYPE_AUDIOSRC, 0, N_("Pulse - PulseAudio Sound Server"), "pulsesrc", NULL,
+      FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
   /* Note: using triangle instead of sine for test sound so we
    * can test the vorbis encoder as well (otherwise it'd compress too well) */
-  {PIPE_TYPE_AUDIOSRC, 0, "Test Sound", "audiotestsrc wave=triangle is-live=true", FALSE,
-      TEST_PIPE_AUDIOSINK, NULL, FALSE},
-  {PIPE_TYPE_AUDIOSRC, 0, "Silence", "audiotestsrc wave=silence is-live=true", FALSE,
-      TEST_PIPE_AUDIOSINK, NULL, FALSE},
-  {PIPE_TYPE_AUDIOSRC, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_AUDIOSINK, NULL,
+  {PIPE_TYPE_AUDIOSRC, 0, N_("Test Sound"), "audiotestsrc wave=triangle is-live=true",
+      NULL, FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
+  {PIPE_TYPE_AUDIOSRC, 0, N_("Silence"), "audiotestsrc wave=silence is-live=true",
+      NULL, FALSE, TEST_PIPE_AUDIOSINK, NULL, FALSE},
+  {PIPE_TYPE_AUDIOSRC, 0, N_("Custom"), NULL, NULL, TRUE, TEST_PIPE_AUDIOSINK, NULL,
       TRUE}
 };
 
 GSTPPipelineDescription videosrc_pipelines[] = {
-  {PIPE_TYPE_VIDEOSRC, 0, "MJPEG (e.g. Zoran v4l device)", "v4lmjpegsrc", FALSE,
+  {PIPE_TYPE_VIDEOSRC, 0, N_("MJPEG (e.g. Zoran v4l device)"), "v4lmjpegsrc", NULL, FALSE,
       TEST_PIPE_VIDEOSINK, NULL, FALSE},
-  {PIPE_TYPE_VIDEOSRC, 0, "QCAM", "qcamsrc", FALSE, TEST_PIPE_VIDEOSINK,
+  {PIPE_TYPE_VIDEOSRC, 0, N_("QCAM"), "qcamsrc", NULL, FALSE, TEST_PIPE_VIDEOSINK,
       NULL, FALSE},
-  {PIPE_TYPE_VIDEOSRC, 0, "Test Input", "videotestsrc is-live=true", FALSE,
+  {PIPE_TYPE_VIDEOSRC, 0, N_("Test Input"), "videotestsrc is-live=true", NULL, FALSE,
       TEST_PIPE_VIDEOSINK, NULL, FALSE},
-  {PIPE_TYPE_VIDEOSRC, 0, "Video for Linux (v4l)", "v4lsrc", FALSE,
+  {PIPE_TYPE_VIDEOSRC, 0, N_("Video for Linux (v4l)"), "v4lsrc", NULL, FALSE,
       TEST_PIPE_VIDEOSINK, NULL, FALSE},
-  {PIPE_TYPE_VIDEOSRC, 0, "Video for Linux 2 (v4l2)", "v4l2src", FALSE,
+  {PIPE_TYPE_VIDEOSRC, 0, N_("Video for Linux 2 (v4l2)"), "v4l2src", NULL, FALSE,
       TEST_PIPE_VIDEOSINK, NULL, FALSE},
-  {PIPE_TYPE_VIDEOSRC, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_VIDEOSINK, NULL,
+  {PIPE_TYPE_VIDEOSRC, 0, N_("Custom"), NULL, NULL, TRUE, TEST_PIPE_VIDEOSINK, NULL,
       TRUE}
 };
 
@@ -154,33 +154,33 @@ GSTPPipelineEditor pipeline_editors[] = {
         G_N_ELEMENTS (audiosink_pipelines),
         (GSTPPipelineDescription *) (audiosink_pipelines), 0,
         GSTPROPS_KEY_DEFAULT_AUDIOSINK,
-        "audiosink_optionmenu", "audiosink_pipeline_entry",
-        "audiosink_test_button",
-      NULL, NULL, NULL},
+        "audiosink_optionmenu", "audiosink_devicemenu",
+				"audiosink_pipeline_entry", "audiosink_test_button",
+      NULL, NULL, NULL, NULL},
   /* videosink pipelines */
   {
         G_N_ELEMENTS (videosink_pipelines),
         (GSTPPipelineDescription *) (videosink_pipelines), 0,
         GSTPROPS_KEY_DEFAULT_VIDEOSINK,
-        "videosink_optionmenu", "videosink_pipeline_entry",
-        "videosink_test_button",
-      NULL, NULL, NULL},
+        "videosink_optionmenu", "videosink_devicemenu",
+        "videosink_pipeline_entry", "videosink_test_button",
+      NULL, NULL, NULL, NULL},
   /* videosrc pipelines */
   {
         G_N_ELEMENTS (videosrc_pipelines),
         (GSTPPipelineDescription *) (videosrc_pipelines), 0,
         GSTPROPS_KEY_DEFAULT_VIDEOSRC,
-        "videosrc_optionmenu", "videosrc_pipeline_entry",
-        "videosrc_test_button",
-      NULL, NULL, NULL},
+        "videosrc_optionmenu", "videosrc_devicemenu",
+        "videosrc_pipeline_entry", "videosrc_test_button",
+      NULL, NULL, NULL, NULL},
   /* audiosrc pipelines */
   {
         G_N_ELEMENTS (audiosrc_pipelines),
         (GSTPPipelineDescription *) (audiosrc_pipelines), 0,
         GSTPROPS_KEY_DEFAULT_AUDIOSRC,
-        "audiosrc_optionmenu", "audiosrc_pipeline_entry",
-        "audiosrc_test_button",
-      NULL, NULL, NULL}
+        "audiosrc_optionmenu", "audiosrc_devicemenu",
+        "audiosrc_pipeline_entry", "audiosrc_test_button",
+      NULL, NULL, NULL, NULL}
 };
 
 gint pipeline_editors_count = G_N_ELEMENTS (pipeline_editors);
